@@ -3,10 +3,10 @@
 from .dynamodb_table import DynamoDBTable
 from ..models import NbaPlayerPerformanceModel
 
-class NbaPlayersStats(DynamoDBTable[NbaPlayerPerformanceModel]):
+class NbaPlayersStatsTable(DynamoDBTable[NbaPlayerPerformanceModel]):
     def __init__(self, environment: str):
         DynamoDBTable.__init__(self, 'nba-players-stats', environment, 'playerId', 'gameDate')
 
-class NbaPlayerPerformances(DynamoDBTable[NbaPlayerPerformanceModel]):
+class NbaPlayerPerformancesTable(DynamoDBTable[NbaPlayerPerformanceModel]):
     def __init__(self, environment: str):
         DynamoDBTable.__init__(self, 'nba-players-stats', environment, 'playerId', 'gameDate')
